@@ -1603,8 +1603,8 @@ gboolean gncEntryRegister (void)
             (QofSetterFunc)gncEntrySetInvTaxIncluded
         },
         {
-            ENTRY_BILL_TAXABLE, QOF_TYPE_BOOLEAN, (QofAccessFunc)gncEntryGetInvTaxable,
-            (QofSetterFunc)gncEntrySetInvTaxable
+            ENTRY_BILL_TAXABLE, QOF_TYPE_BOOLEAN, (QofAccessFunc)gncEntryGetBillTaxable,
+            (QofSetterFunc)gncEntrySetBillTaxable
         },
         {
             ENTRY_BILL_TAX_INC, QOF_TYPE_BOOLEAN, (QofAccessFunc)gncEntryGetBillTaxIncluded,
