@@ -71,6 +71,12 @@ static void gtva_setup_column_renderer_edited_cb(GncTreeViewAccount *account_vie
         GtkCellRenderer *renderer,
         GncTreeViewAccountColumnTextEdited col_edited_cb);
 
+static void tax_info_data_func (GtkTreeViewColumn *col,
+                                GtkCellRenderer   *renderer,
+                                GtkTreeModel      *model,
+                                GtkTreeIter       *iter,
+                                gpointer           view);
+
 typedef struct GncTreeViewAccountPrivate
 {
     AccountViewInfo avi;
@@ -459,6 +465,75 @@ sort_by_total_period_value (GtkTreeModel *f_model,
     return sort_by_xxx_period_value (f_model, f_iter_a, f_iter_b, TRUE);
 }
 
+/************************************************************/
+/*                 Tax_Info data function                   */
+/************************************************************/
+
+/*
+ * The tax-info column in the account tree view is based on the
+ * combination of two columns in the account tree model. The data
+ * function displays only the the data in the
+ * GNC_TREE_MODEL_ACCOUNT_COL_TAX_INFO model column if the row is
+ * expanded; otherwise it combines it with the data
+ * in the GNC_TREE_MODEL_ACCOUNT_COL_TAX_INFO_SUB_ACCT model column.
+ */
+static void
+tax_info_data_func (GtkTreeViewColumn *col,
+                    GtkCellRenderer   *renderer,
+                    GtkTreeModel      *model,
+                    GtkTreeIter       *iter,
+                    gpointer           view)
+{
+    gchar *tax_info = NULL;
+    GtkTreePath *path;
+
+    gtk_tree_model_get(model,
+                       iter,
+                       GNC_TREE_MODEL_ACCOUNT_COL_TAX_INFO,
+                       &tax_info,
+                       -1);
+
+    path = gtk_tree_model_get_path(model, iter);
+    if (gtk_tree_view_row_expanded(GTK_TREE_VIEW(view), path))
+        g_object_set(renderer, "text",
+                     (tax_info == NULL ? "" : tax_info), NULL);
+    else
+    {
+        gchar *tax_info_sub_acct = NULL;
+
+        gtk_tree_model_get(model,
+                           iter,
+                           GNC_TREE_MODEL_ACCOUNT_COL_TAX_INFO_SUB_ACCT,
+                           &tax_info_sub_acct,
+                           -1);
+        if ((safe_strcmp (tax_info_sub_acct, "") == 0) ||
+                (tax_info_sub_acct == NULL))
+            g_object_set(renderer, "text",
+                         (tax_info == NULL ? "" : tax_info), NULL);
+        else
+        {
+            if ((safe_strcmp (tax_info, "") == 0) ||
+                    (tax_info == NULL))
+                g_object_set(renderer, "text",
+                             (tax_info_sub_acct == NULL ? "" : tax_info_sub_acct),
+                             NULL);
+            else
+            {
+                gchar *combined_tax_info;
+                combined_tax_info = g_strdup_printf ("%s; %s",
+                                                     (tax_info == NULL ? "" : tax_info),
+                                                     (tax_info_sub_acct == NULL ? "" :
+                                                      tax_info_sub_acct));
+                g_object_set(renderer, "text", combined_tax_info, NULL);
+                g_free(combined_tax_info);
+            }
+        }
+        g_free(tax_info_sub_acct);
+    }
+    g_free(tax_info);
+    gtk_tree_path_free(path);
+}
+
 /************************************************************/
 /*                    New View Creation                     */
 /************************************************************/
@@ -477,6 +552,8 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
     GtkTreePath *virtual_root_path = NULL;
     const gchar *sample_type, *sample_commodity;
     GncTreeViewAccountPrivate *priv;
+    GtkTreeViewColumn *tax_info_column;
+    GtkCellRenderer *renderer;
 
     ENTER(" ");
     /* Create our view */
@@ -644,11 +721,18 @@ gnc_tree_view_account_new_with_root (Account *root, gboolean show_root)
                                     GNC_TREE_MODEL_ACCOUNT_COL_NOTES,
                                     GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
                                     sort_by_string);
-    gnc_tree_view_add_text_column(view, _("Tax Info"), "tax-info", NULL,
-                                  "Sample tax info.",
-                                  GNC_TREE_MODEL_ACCOUNT_COL_TAX_INFO,
-                                  GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
-                                  sort_by_string);
+    tax_info_column
+    = gnc_tree_view_add_text_column(view, _("Tax Info"), "tax-info", NULL,
+                                    "Sample tax info.",
+                                    GNC_TREE_MODEL_ACCOUNT_COL_TAX_INFO,
+                                    GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS,
+                                    sort_by_string);
+    renderer = gnc_tree_view_column_get_renderer(tax_info_column);
+    gtk_tree_view_column_set_cell_data_func(tax_info_column,
+                                            renderer,
+                                            tax_info_data_func,
+                                            GTK_TREE_VIEW(view),
+                                            NULL);
     gnc_tree_view_add_toggle_column(view, _("Placeholder"),
                                     /* Translators: This string has a context prefix; the translation
                                     	must only contain the part after the | character. */
@@ -2208,18 +2292,24 @@ gnc_tree_view_account_name_edited_cb(Account *account, GtkTreeViewColumn *col, c
 void
 gnc_tree_view_account_code_edited_cb(Account *account, GtkTreeViewColumn *col, const gchar *new_code)
 {
+    if (safe_strcmp(xaccAccountGetCode(account), new_code) == 0)
+	return;
     xaccAccountSetCode(account, new_code);
 }
 
 void
 gnc_tree_view_account_description_edited_cb(Account *account, GtkTreeViewColumn *col, const gchar *new_desc)
 {
+    if (safe_strcmp(xaccAccountGetDescription(account), new_desc) == 0)
+	return;
     xaccAccountSetDescription(account, new_desc);
 }
 
 void
 gnc_tree_view_account_notes_edited_cb(Account *account, GtkTreeViewColumn *col, const gchar *new_notes)
 {
+    if (safe_strcmp(xaccAccountGetNotes(account), new_notes) == 0)
+	return;
     xaccAccountSetNotes(account, new_notes);
 }
 
