@@ -411,8 +411,8 @@ gnc_ab_memo_to_gnc(const AB_TRANSACTION *ab_trans)
     const gchar *ab_remote_bankcode =
         AB_Transaction_GetRemoteBankCode(ab_trans);
 
-    gchar *ab_other_accountid = g_strdup(ab_remote_accountnumber);
-    gchar *ab_other_bankcode = g_strdup(ab_remote_bankcode);
+    gchar *ab_other_accountid = g_strdup(ab_remote_accountnumber ? ab_remote_accountnumber : "");
+    gchar *ab_other_bankcode = g_strdup(ab_remote_bankcode ? ab_remote_bankcode : "");
 
     gboolean have_accountid;
     gboolean have_bankcode;
