@@ -16,20 +16,22 @@
 ;;; along with this program; if not, contact:
 ;;;
 ;;; Free Software Foundation           Voice:  +1-617-542-5942
-;;; 59 Temple Place - Suite 330        Fax:    +1-617-542-2652
-;;; Boston, MA  02111-1307,  USA       gnu@gnu.org
+;;; 51 Franklin Street, Fifth Floor    Fax:    +1-617-542-2652
+;;; Boston, MA  02110-1301,  USA       gnu@gnu.org
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-;(use-modules (gnucash process))
+(define-module (gnucash price-quotes))
 
-(gnc:support "price-quotes.scm")
-
-(gnc:depend "process.scm")
-(gnc:depend "gnc-numeric.scm")
-(gnc:depend "utilities.scm")
-(gnc:depend "engine-utilities.scm")
+(export yahoo-get-historical-quotes)
+(export gnc:book-add-quotes) ;; called from gnome/dialog-price-edit-db.c
+(export gnc:price-quotes-install-sources)
 
+(use-modules (gnucash main)) ;; FIXME: delete after we finish modularizing.
+(use-modules (gnucash gnc-module))
+(use-modules (gnucash core-utils))
 
+(gnc:module-load "gnucash/gnome-utils" 0) ;; for gnucash-ui-is-running
+(gnc:module-load "gnucash/app-utils" 0)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
@@ -41,6 +43,35 @@
 
 ;; (use-modules (srfi srfi-19)) when available (see below).
 
+(define (item-list->hash! lst hash
+			  getkey getval
+			  hashref hashset 
+			  list-duplicates?)
+  ;; Takes a list of the form (item item item item) and returns a hash
+  ;; formed by traversing the list, and getting the key and val from
+  ;; each item using the supplied get-key and get-val functions, and
+  ;; building a hash table from the result using the given hashref and
+  ;; hashset functions.  list-duplicates? determines whether or not in
+  ;; the resulting hash, the value for a given key is a list of all
+  ;; the values associated with that key in the input or just the
+  ;; first one encountered.
+
+  (define (handle-item item)
+    (let* ((key (getkey item))
+	   (val (getval item))
+	   (existing-val (hashref hash key)))
+
+      (if (not list-duplicates?)
+	  ;; ignore if not first value.
+	  (if (not existing-val) (hashset hash key val))
+	  ;; else result is list.
+	  (if existing-val
+	      (hashset hash key (cons val existing-val))
+	      (hashset hash key (list val))))))
+  
+  (for-each handle-item lst)
+  hash)
+
 (define (yahoo-get-historical-quotes symbol
                                      start-year start-month start-day
                                      end-year end-month end-day)
@@ -206,6 +237,42 @@
                 result)
             #f))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define gnc:*finance-quote-check*
+  (string-append (gnc-path-get-bindir) "/gnc-fq-check"))
+
+(define (gnc:fq-check-sources)
+  (let ((program '())
+        (from-child #f))
+
+    (define (start-program)
+      (if (not (string-null? gnc:*finance-quote-check*))
+          (set! program (gnc-spawn-process-async
+                         (list "perl" "-w" gnc:*finance-quote-check*) #t))))
+
+    (define (get-sources)
+      (if (not (null? program))
+          (let ((results #f))
+            (set! from-child (fdes->inport (gnc-process-get-fd program 1)))
+            (catch
+             #t
+             (lambda ()
+               (set! results (read from-child))
+               (gnc:debug "results: " results)
+               results)
+             (lambda (key . args)
+               key)))))
+
+    (define (kill-program)
+      (if (not (null? program))
+          (gnc-detach-process program #t)))
+
+    (dynamic-wind
+        start-program
+        get-sources
+        kill-program)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
 ;; Finance::Quote based instantaneous quotes -- used by the
@@ -219,8 +286,7 @@
 ;; src/engine/gnc-pricedb.h
 
 (define gnc:*finance-quote-helper*
-  (string-append (gnc:config-var-value-get gnc:*share-dir*)
-                 "/finance-quote-helper"))
+  (string-append (gnc-path-get-bindir) "/gnc-fq-helper"))
 
 (define (gnc:fq-get-quotes requests)
   ;; requests should be a list where each item is of the form
@@ -240,7 +306,7 @@
   ;; symbol if the corresponding method call fails, or a list
   ;; otherwise. A quote-result list will contain the symbol
   ;; representing the item being quoted, followed by an alist
-  ;; detailing the quote data from finance-quote-helper.
+  ;; detailing the quote data from gnc-fq-helper.
   ;;
   ;; Possible error symbols and their meanings are:
   ;;   missing-lib    One of the required perl libs is missing
@@ -257,86 +323,66 @@
   ;;
   ;; Also note that any given value in the alist might be
   ;; 'failed-conversion if the Finance::Quote result for that field
-  ;; was unparsable.  See the finance-quote-helper for more details
+  ;; was unparsable.  See the gnc-fq-helper for more details
   ;; about it's output.
 
-  (let ((quoter #f))
+  (let ((quoter '())
+        (to-child #f)
+        (from-child #f))
 
     (define (start-quoter)
-      (set! quoter (gnc:run-sub-process #f
-                                        gnc:*finance-quote-helper*
-                                        gnc:*finance-quote-helper*)))
+      (if (not (string-null? gnc:*finance-quote-helper*))
+          (set! quoter (gnc-spawn-process-async
+                        (list "perl" "-w" gnc:*finance-quote-helper*) #t))))
 
     (define (get-quotes)
-      (and quoter
-           (let ((to-child (caddr quoter))
-                 (from-child (cadr quoter)))
-             (map
-              (lambda (request)
-                (write (list 'handling-request request))
-                (newline)
-                ;; we need to display the first element (the method, so it
-                ;; won't be quoted) and then write the rest
-                (display #\( to-child)
-                (display (car request) to-child)
-                (display " " to-child)
-                (for-each (lambda (x) (write x to-child)) (cdr request))
-                (display #\) to-child)
-                (newline to-child)
-                (force-output to-child)
-                (read from-child))
+      (if (not (null? quoter))
+          (let ((results #f))
+            (set! to-child (fdes->outport (gnc-process-get-fd quoter 0)))
+            (set! from-child (fdes->inport (gnc-process-get-fd quoter 1)))
+            (map
+             (lambda (request)
+               (catch
+                #t
+                (lambda ()
+                  (gnc:debug "handling-request: " request)
+                  ;; we need to display the first element (the method, so it
+                  ;; won't be quoted) and then write the rest
+                  (display #\( to-child)
+                  (display (car request) to-child)
+                  (display " " to-child)
+                  (for-each (lambda (x) (write x to-child)) (cdr request))
+                  (display #\) to-child)
+                  (newline to-child)
+                  (force-output to-child)
+                  (set! results (read from-child))
+                  (gnc:debug "results: " results)
+                  results)
+                (lambda (key . args)
+                  key)))
              requests))))
 
     (define (kill-quoter)
-      (and quoter
-           (let ((pid (car quoter)))
-             (close-input-port (cadr quoter))
-             (close-output-port (caddr quoter))
-             (gnc:cleanup-sub-process (car quoter) 1))))
+      (if (not (null? quoter))
+          (gnc-detach-process quoter #t)))
 
     (dynamic-wind
         start-quoter
         get-quotes
         kill-quoter)))
 
-(define (gnc:book-add-quotes book)
+(define (gnc:book-add-quotes window book)
 
-  (define (find-quotables group)
-    ;; Return a list of accounts for whose commodities we should get
-    ;; quotes.
-    (define (quotable-currency-account? a)
-      (let ((currency (gnc:account-get-currency a))
-            (security (gnc:account-get-security a)))
-        (and (equal? (gnc:commodity-get-namespace currency) "ISO4217")
-             (equal? (gnc:commodity-get-namespace security) "ISO4217"))))
-
-    (define (quotable-account? a)
-      (let ((type (gw:enum-<gnc:AccountType>-val->sym (gnc:account-get-type a)
-                                                      #f))
-	    (src (gnc:account-get-price-src a)))
-
-        (if (not type) (set! type '()))
-        (if (symbol? type) (set! type (list type)))
-        (if (and src
-		 (or (memq 'stock type)
-		     (memq 'mutual-fund type)
-		     (and (memq 'currency type)
-                          (quotable-currency-account? a))))
-	    a
-	    #f)))
-
-    (filter quotable-account? (gnc:group-get-subaccounts group)))
-
-  (define (accounts->fq-call-data account-list)
-    ;; Take a list of accounts that should be "quotable" -- i.e. they
-    ;; have a price-source, and are of the right type, and return a
+  (define (book->commodity->fq-call-data book)
+    ;; Call helper that walks all of the defined commodities to see if
+    ;; any are marked for quote retrieval.  This function returns a
     ;; list of info needed for the relevant Finance::Quote calls, and
     ;; a list of the corresponding commodities.  Also perform a bit of
     ;; optimization, merging calls for symbols to the same
     ;; Finance::Quote method.
     ;; 
     ;; Returns a list of the info needed for a set of calls to
-    ;; finance-quote-helper.  Each item will of the list will be of the
+    ;; gnc-fq-helper.  Each item will of the list will be of the
     ;; form:
     ;;
     ;; (("yahoo" (commodity-1 currency-1 tz-1)
@@ -345,78 +391,44 @@
     ;;                     (commodity-4 currency-4 tz-4) ...)
     ;;  ...)
 
-  (define (src->fq-method-sym src)
-    (cond
-     ((string=? "YAHOO" src) 'yahoo)
-     ((string=? "YAHOO_EUROPE" src) 'yahoo-europe)
-     ((string=? "FIDELITY" src) 'fidelity)
-     ((string=? "TRPRICE" src) 'troweprice)
-     ((string=? "VANGUARD" src) 'vanguard)
-     ((string=? "ASX" src) 'asx)
-     ((string=? "TIAACREF" src) 'tiaacref)
-     ((string=? "TRUSTNET" src) 'trustnet)
-     ((string=? "CURRENCY" src) 'currency)
-     (else #f)))
+    (let* ((ct (gnc-commodity-table-get-table book))
+	   (big-list
+	    (gnc-commodity-table-get-quotable-commodities
+	     ct))
+	   (commodity-list #f)
+	   (currency-list (filter
+			   (lambda (a) (not (equal? (cadr a) (caddr a))))
+			   (call-with-values 
+                               (lambda () (partition!
+                                           (lambda (cmd)
+                                             (not (string=? (car cmd) "currency")))
+                                           big-list))
+                             (lambda (a b) (set! commodity-list a) b))))
+	   (quote-hash (make-hash-table 31)))
 
-  ;; NOTE: If you modify this, please update finance-quote-helper.in as well.
-  (define (fq-method-sym->str src-sym)
-    (case src-sym
-     ((yahoo) "yahoo")
-     ((yahoo-europe) "yahoo_europe")
-     ((fidelity) "fidelity_direct")
-     ((troweprice) "troweprice_direct")
-     ((vanguard) "vanguard")
-     ((asx) "asx")
-     ((tiaacref) "tiaacref")
-     ((trustnet) "trustnet")
-     ((currency) "currency")
-     (else #f)))
+      (if (and (null? commodity-list) (null? currency-list))
+	  #f
+	  (begin
 
-  (define (account->fq-cmd account)
-    ;; Returns (cons fq-method-sym
-    ;;               (list commodity currency assumed-timezone-str))
-    (let* ((commodity (gnc:account-get-commodity account))
-           (currency (gnc:account-get-currency account))
-           (src (and account (gnc:account-get-price-src account)))
-           (tz (gnc:account-get-quote-tz account))
-	   (fq-method-sym (and src (src->fq-method-sym src)))
-           (mnemonic (and commodity (gnc:commodity-get-mnemonic commodity))))
-      (and
-       commodity
-       currency
-       fq-method-sym
-       mnemonic
-       (list fq-method-sym commodity currency tz))))
+	    ;; Now collect symbols going to the same backend.
+	    (item-list->hash! commodity-list quote-hash car cdr hash-ref hash-set! #t)
 
-  (let* ((big-list (delete #f (map account->fq-cmd account-list)))
-         (cmd-list #f)
-         (currency-cmd-list (call-with-values 
-                             (lambda () (partition!
-                                         (lambda (cmd)
-                                           (not (eq? (car cmd) 'currency)))
-                                         big-list))
-                             (lambda (a b) (set! cmd-list a) b)))
-         (cmd-hash (make-hash-table 31)))
-
-    ;; Now collect symbols going to the same backend.
-    (item-list->hash! cmd-list cmd-hash car cdr hashq-ref hashq-set! #t)
-
-    ;; Now translate to just what finance-quote-helper expects.
-    (append
-     (hash-fold
-      (lambda (key value prior-result)
-        (cons (cons (fq-method-sym->str key) value)
-              prior-result))
-      '()
-      cmd-hash)
-     (map (lambda (cmd) (cons (fq-method-sym->str (car cmd)) (list (cdr cmd))))
-          currency-cmd-list))))
+	    ;; Now translate to just what gnc-fq-helper expects.
+	    (append
+	     (hash-fold
+	      (lambda (key value prior-result)
+		(cons (cons key value)
+		      prior-result))
+	      '()
+	      quote-hash)
+	     (map (lambda (cmd) (cons (car cmd) (list (cdr cmd))))
+		  currency-list))))))
 
   (define (fq-call-data->fq-calls fq-call-data)
-    ;; take an output element from accounts->fq-call-data and return a
-    ;; list where the gnc_commodities have been converted to their
-    ;; fq-suitable symbol strings.  i.e. turn the former into the
-    ;; latter:
+    ;; take an output element from book->commodity->fq-call-data and
+    ;; return a list where the gnc_commodities have been converted to
+    ;; their fq-suitable symbol strings.  i.e. turn the former into
+    ;; the latter:
     ;;
     ;; ("yahoo" (commodity-1 currency-1 tz-1)
     ;;          (commodity-2 currency-2 tz-2) ...)
@@ -427,14 +439,14 @@
     (if (equal? (car fq-call-data) "currency")
         (map (lambda (quote-item-info)
                (list (car fq-call-data)
-                     (gnc:commodity-get-mnemonic (car quote-item-info))
-                     (gnc:commodity-get-mnemonic (cadr quote-item-info))))
+                     (gnc-commodity-get-mnemonic (car quote-item-info))
+                     (gnc-commodity-get-mnemonic (cadr quote-item-info))))
              (cdr fq-call-data))
         (list
          (cons (car fq-call-data)
                (map
                 (lambda (quote-item-info)
-                  (gnc:commodity-get-mnemonic (car quote-item-info)))
+                  (gnc-commodity-get-mnemonic (car quote-item-info)))
                 (cdr fq-call-data))))))
 
   (define (fq-results->commod-tz-quote-triples fq-call-data fq-results)
@@ -470,7 +482,7 @@
                     (and (pair? alist-item)
                          (not (eq? 'failed-conversion (cdr alist-item)))))
                   (cdr call-result)))
-            ;; OK, data is good (as far as we can tell.
+            ;; OK, data is good (as far as we can tell).
             (set! result-list
                   (cons (list (car call-data)
                               (caddr call-data)
@@ -503,13 +515,9 @@
              (reverse result-list)))))
 
   (define (timestr->time-pair timestr time-zone)
-    (let ((broken-down (strptime "%Y-%m-%d %H:%M:%S" timestr)))
-      (if (not (= (string-length timestr) (cdr broken-down)))
-          #f
-          (cons (car (if time-zone
-                         (mktime (car broken-down) time-zone)
-                         (mktime (car broken-down))))
-                0))))
+    ;; time-zone is ignored currently
+    (cons (gnc-parse-time-to-timet timestr "%Y-%m-%d %H:%M:%S")
+          0))
 
   (define (commodity-tz-quote-triple->price book c-tz-quote-triple)
     ;; return a string like "NASDAQ:CSCO" on error, or a price on
@@ -521,11 +529,11 @@
            (price #f)
            (price-type #f)
            (currency-str (assq-ref quote-data 'currency))
-           (commodity-table (gnc:book-get-commodity-table book))
+           (commodity-table (gnc-commodity-table-get-table book))
            (currency
             (and commodity-table
                  (string? currency-str)
-                 (gnc:commodity-table-lookup commodity-table
+                 (gnc-commodity-table-lookup commodity-table
                                              "ISO4217"
                                              (string-upcase currency-str)))))
 
@@ -548,7 +556,7 @@
       ;; FIXME: SIGFIGS is not what we want here...
       (if price
           (set! price
-                (gnc:double-to-gnc-numeric price
+                (double-to-gnc-numeric price
                                            GNC-DENOM-AUTO
                                            (logior (GNC-DENOM-SIGFIGS 9)
                                                    GNC-RND-ROUND))))
@@ -559,40 +567,40 @@
 
       (if (not (and commodity currency gnc-time price price-type))
           (string-append
-           currency-str ":" (gnc:commodity-get-mnemonic commodity))
-          (let ((gnc-price (gnc:price-create)))
+           currency-str ":" (gnc-commodity-get-mnemonic commodity))
+          (let ((gnc-price (gnc-price-create book)))
             (if (not gnc-price)
                 (string-append
-                 currency-str ":" (gnc:commodity-get-mnemonic commodity))
+                 currency-str ":" (gnc-commodity-get-mnemonic commodity))
                 (begin
-                  (gnc:price-set-commodity gnc-price commodity)
-                  (gnc:price-set-currency gnc-price currency)
-                  (gnc:price-set-time gnc-price gnc-time)
-                  (gnc:price-set-source gnc-price "Finance::Quote")
-                  (gnc:price-set-type gnc-price price-type)
-                  (gnc:price-set-value gnc-price price)
+				  (gnc-price-begin-edit gnc-price)
+                  (gnc-price-set-commodity gnc-price commodity)
+                  (gnc-price-set-currency gnc-price currency)
+                  (gnc-price-set-time gnc-price gnc-time)
+                  (gnc-price-set-source gnc-price "Finance::Quote")
+                  (gnc-price-set-typestr gnc-price price-type)
+                  (gnc-price-set-value gnc-price price)
+				  (gnc-price-commit-edit gnc-price)
                   gnc-price))))))
 
   (define (book-add-prices! book prices)
-    (let ((pricedb (gnc:book-get-pricedb book)))
+    (let ((pricedb (gnc-pricedb-get-db book)))
       (for-each
        (lambda (price)
-         (gnc:pricedb-add-price pricedb price)
-         (gnc:price-unref price))
+         (gnc-pricedb-add-price pricedb price)
+         (gnc-price-unref price))
        prices)))
 
   ;; FIXME: uses of gnc:warn in here need to be cleaned up.  Right
   ;; now, they'll result in funny formatting.
 
-  (let* ((group (gnc:book-get-group book))
-         (quotables (and group (find-quotables group)))
-         (fq-call-data (and quotables (accounts->fq-call-data quotables)))
+  (let* ((fq-call-data (book->commodity->fq-call-data book))
          (fq-calls (and fq-call-data
                         (apply append
                                (map fq-call-data->fq-calls fq-call-data))))
          (fq-results (and fq-calls (gnc:fq-get-quotes fq-calls)))
          (commod-tz-quote-triples
-          (and fq-results (not (member 'missing-lib fq-results))
+          (and fq-results (list? (car fq-results))
                (fq-results->commod-tz-quote-triples fq-call-data fq-results)))
          ;; At this point commod-tz-quote-triples will either be #f or a
          ;; list of items. Each item will either be (commodity
@@ -603,9 +611,9 @@
                              (if (car cq-pair)
                                  #f
                                  (string-append
-                                  (gnc:commodity-get-namespace (cdr cq-pair))
+                                  (gnc-commodity-get-namespace (cdr cq-pair))
                                   ":"
-                                  (gnc:commodity-get-mnemonic (cdr cq-pair)))))
+                                  (gnc-commodity-get-mnemonic (cdr cq-pair)))))
                            commod-tz-quote-triples)))
          ;; strip out the "bad" ones from above.
          (ok-syms
@@ -614,27 +622,49 @@
          (keep-going? #t))
 
     (cond
+     ((eq? fq-call-data #f)
+      (set! keep-going? #f)
+      (if (gnucash-ui-is-running)
+          (gnc-error-dialog window (_ "No commodities marked for quote retrieval."))
+	  (gnc:warn (_ "No commodities marked for quote retrieval."))))
+     ((eq? fq-results #f)
+      (set! keep-going? #f)
+      (if (gnucash-ui-is-running)
+          (gnc-error-dialog window (_ "Unable to get quotes or diagnose the problem."))
+	  (gnc:warn (_ "Unable to get quotes or diagnose the problem."))))
      ((member 'missing-lib fq-results)
       (set! keep-going? #f)
-      (if (gnc:ui-is-running?)
-          (gnc:error-dialog
+      (if (gnucash-ui-is-running)
+          (gnc-error-dialog window
            (_ "You are missing some needed Perl libraries.
-Run 'update-finance-quote' as root to install them."))
+Run 'gnc-fq-update' as root to install them."))
           (gnc:warn (_ "You are missing some needed Perl libraries.
-Run 'update-finance-quote' as root to install them.") "\n")))
-     ((and (not commod-tz-quote-triples) (gnc:ui-is-running?))
-      (gnc:error-dialog
+Run 'gnc-fq-update' as root to install them.") "\n")))
+     ((member 'system-error fq-results)
+      (set! keep-going? #f)
+      (if (gnucash-ui-is-running)
+          (gnc-error-dialog window
+           (_ "There was a system error while retrieving the price quotes."))
+          (gnc:warn (_ "There was a system error while retrieving the price quotes.") "\n")))
+     ((not (list? (car fq-results)))
+      (set! keep-going? #f)
+      (if (gnucash-ui-is-running)
+          (gnc-error-dialog window
+           (_ "There was an unknown error while retrieving the price quotes."))
+          (gnc:warn (_ "There was an unknown error while retrieving the price quotes.") "\n")))
+     ((and (not commod-tz-quote-triples) (gnucash-ui-is-running))
+      (gnc-error-dialog window
        (_ "Unable to get quotes or diagnose the problem."))
        (set! keep-going? #f))
      ((not commod-tz-quote-triples)
       (gnc:warn (_ "Unable to get quotes or diagnose the problem."))
       (set! keep-going? #f))
      ((not (null? problem-syms))
-      (if (gnc:ui-is-running?)
+      (if (gnucash-ui-is-running)
           (if (and ok-syms (not (null? ok-syms)))
               (set!
                keep-going?
-               (gnc:verify-dialog
+               (gnc-verify-dialog window #t
                 (call-with-output-string
                  (lambda (p)
                    (display (_ "Unable to retrieve quotes for these items:") p)
@@ -642,10 +672,9 @@ Run 'update-finance-quote' as root to install them.") "\n")))
                    (display "  " p)
                    (display (string-join problem-syms "\n  ") p)
                    (newline p)
-                   (display (_ "Continue using only the good quotes?") p)))
-                #t))
+                   (display (_ "Continue using only the good quotes?") p)))))
               (begin
-                (gnc:error-dialog
+                (gnc-error-dialog window
                  (call-with-output-string
                   (lambda (p)
                     (display
@@ -671,10 +700,10 @@ Run 'update-finance-quote' as root to install them.") "\n")))
                           (commodity-tz-quote-triple->price book triple))
                         ok-syms)))
        (if (any string? prices)
-           (if (gnc:ui-is-running?)
+           (if (gnucash-ui-is-running)
                (set!
                 keep-going?
-                (gnc:verify-dialog
+                (gnc-verify-dialog window #t
                  (call-with-output-string
                   (lambda (p)
                     (display (_ "Unable to create prices for these items:") p)
@@ -682,8 +711,7 @@ Run 'update-finance-quote' as root to install them.") "\n")))
                     (display "  " p)
                     (display (string-join (filter string? prices) "\n  ") p)
                     (newline p)
-                    (display (_ "Add remaining good quotes?") p)))
-                 #t))
+                    (display (_ "Add remaining good quotes?") p)))))
                (gnc:warn
                 (call-with-output-string
                  (lambda (p)
@@ -700,21 +728,6 @@ Run 'update-finance-quote' as root to install them.") "\n")))
                                    (lambda (x) (not (string? x)))
                                    prices)))))))
 
-(define (gnc:add-quotes-to-book-at-url url)
-  (let* ((book (gnc:url->loaded-book url #f #f))
-         (quote-ok? (and book (gnc:book-add-quotes book))))
-
-    (if (not quote-ok?) (gnc:msg "book-add-quotes failed"))
-    (and book (gnc:book-save book))
-    (if (not (eq? 'no-err
-                  (gw:enum-<gnc:BackendError>-val->sym
-                   (gnc:book-get-error book) #f)))
-        (set! quote-ok? #f))
-    (if (not quote-ok?)
-        (gnc:msg "book-save failed " (gnc:book-get-error book)))
-    (and book (gnc:book-destroy book))
-    quote-ok?))
-
 ; (define (get-1-quote exchange . items)
 ;   (let ((cmd (apply list 'fetch exchange items))
 ; 	(quoter (run-sub-process #f
@@ -728,3 +741,12 @@ Run 'update-finance-quote' as root to install them.") "\n")))
 ; 	   (close-input-port (cadr quoter))
 ; 	   (close-output-port (caddr quoter))
 ; 	   result))))
+
+(define (gnc:price-quotes-install-sources)
+  (let ((sources (gnc:fq-check-sources)))
+    (if (list? sources)
+	(begin
+      (format #t "Found Finance::Quote version ~A" (car sources))
+      (newline)
+	  (gnc:msg "Found Finance::Quote version " (car sources))
+	  (gnc-quote-source-set-fq-installed (cdr sources))))))
